Generate prediction intervals for new data using a fitted conformal prediction object.
Usage
# S3 method for class 'predictset_reg'
predict(object, newdata, ...)Arguments
- object
A
predictset_regobject.- newdata
A numeric matrix or data frame of new predictor variables.
- ...
Additional arguments. For Mondrian objects, pass
groups_new(a factor or character vector of group labels for each observation innewdata). For weighted conformal objects, passweights_new(importance weights for each row ofnewdata).