Generate prediction intervals for new data using a fitted conformal prediction object.
Usage
# S3 method for class 'predictset_reg'
predict(object, newdata, ...)Generate prediction intervals for new data using a fitted conformal prediction object.
# S3 method for class 'predictset_reg'
predict(object, newdata, ...)